#!/usr/bin/env python
# -*- coding: utf-8 -*-

from easyleetcode.web.main import run

__author__ = 'Jiang.XinFa'

__all__ = ["run"]
